rewrite

package
v0.0.0-...-14e6c00 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 23, 2018 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

/ rewrite provides tools to dynamically transform modules to chenge their providers using reflection.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RewriteAnnotations

func RewriteAnnotations(
	module inject.Module,
	annotationsToRewrite AnnotationsMapping,
) inject.DynamicModule

/ Generate a module that takes all input module's providers and replaces specified annotations / according to the `annotationsToRewrite` map.

Types

type AnnotationsMapping

type AnnotationsMapping map[inject.Annotation]inject.Annotation

/ Annotations mapping: a map from annotations to be replaced to annotations to replace them with.

Jump to