Documentation
¶
Overview ¶
/ rewrite provides tools to dynamically transform modules to chenge their providers using reflection.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RewriteAnnotations ¶
func RewriteAnnotations( module inject.Module, annotationsToRewrite AnnotationsMapping, ) inject.DynamicModule
/ Generate a module that takes all input module's providers and replaces specified annotations / according to the `annotationsToRewrite` map.
Types ¶
type AnnotationsMapping ¶
type AnnotationsMapping map[inject.Annotation]inject.Annotation
/ Annotations mapping: a map from annotations to be replaced to annotations to replace them with.
Click to show internal directories.
Click to hide internal directories.